searchData={"items":[{"type":"module","title":"ForexFactory","doc":"Elixir library for `https://www.forexfactory.com` API.","ref":"ForexFactory.html"},{"type":"function","title":"ForexFactory.currencies/0","doc":"","ref":"ForexFactory.html#currencies/0"},{"type":"function","title":"ForexFactory.data/2","doc":"Return data series for a given `event` or error if something goes wrong.\n\n    iex> ForexFactory.Events.Inflation.CPI |> ForexFactory.event!(:USD) |> ForexFactory.data(limit: 1)\n    {:ok,\n     %{\n       \"data\" => %{\n         \"events\" => [\n           %{\n             \"actual\" => 3.2,\n             \"actual_formatted\" => \"3.2%\",\n             \"date\" => \"Mar 12, 2024\",\n             \"dateline\" => 1710246600,\n             \"forecast\" => 3.1,\n             \"forecast_formatted\" => \"3.1%\",\n             \"id\" => 136044,\n             \"is_active\" => false,\n             \"is_most_recent\" => true,\n             \"revision\" => nil,\n             \"revision_formatted\" => nil\n           }\n         ],\n         \"future_timestamps\" => [1712005200],\n         \"past_timestamps\" => [1707831000]\n       },\n       \"meta\" => %{\n         \"decimals\" => 1,\n         \"ebase_event_id\" => 884,\n         \"interval_name\" => \"MN1\",\n         \"is_more\" => true,\n         \"zero_line\" => 0\n       }\n    }}\n\n    iex>  nil |> ForexFactory.data(limit: 1)\n    {:error, \"nil event\"}","ref":"ForexFactory.html#data/2"},{"type":"function","title":"ForexFactory.event/2","doc":"Return a specific event for given `type` and `currency` or error if not found.\n\n    iex> ForexFactory.Events.Inflation.CoreCPI |> ForexFactory.event(:USD)\n    {:ok,\n      %ForexFactory.Event{\n      id: \"136038\",\n      type: ForexFactory.Events.Inflation.CoreCPI,\n      currency: :USD,\n      frequency: :MoM\n      }}\n\n    iex> ForexFactory.Events.Inflation.CoreCPI |> ForexFactory.event(:NZD)\n    {:error,\n      \"missing 'NZD' event of type Elixir.ForexFactory.Events.Inflation.CoreCPI\"}","ref":"ForexFactory.html#event/2"},{"type":"function","title":"ForexFactory.event!/2","doc":"Return a specific event for given `type` and `currency` or raise error if not found.\n\n    iex> ForexFactory.Events.Inflation.CoreCPI |> ForexFactory.event!(:USD)\n    %ForexFactory.Event{\n      id: \"136038\",\n      type: ForexFactory.Events.Inflation.CoreCPI,\n      currency: :USD,\n      frequency: :MoM\n    }\n\n    iex> ForexFactory.Events.Inflation.CoreCPI |> ForexFactory.event!(:NZD)\n    ** (ArgumentError) missing 'NZD' event of type Elixir.ForexFactory.Events.Inflation.CoreCPI","ref":"ForexFactory.html#event!/2"},{"type":"function","title":"ForexFactory.events/1","doc":"Return all events for a given `type`.\n\n    iex> ForexFactory.Events.Inflation.CoreCPI |> ForexFactory.events()\n    [\n      %ForexFactory.Event{\n        id: \"136038\",\n        type: ForexFactory.Events.Inflation.CoreCPI,\n        currency: :USD,\n        frequency: :MoM\n      },\n      %ForexFactory.Event{\n        id: \"139672\",\n        type: ForexFactory.Events.Inflation.CoreCPI,\n        currency: :JPY,\n        frequency: :YoY\n      },\n      %ForexFactory.Event{\n        id: \"138961\",\n        type: ForexFactory.Events.Inflation.CoreCPI,\n        currency: :EUR,\n        frequency: :YoY\n      }\n    ]","ref":"ForexFactory.html#events/1"},{"type":"type","title":"ForexFactory.currency/0","doc":"","ref":"ForexFactory.html#t:currency/0"},{"type":"type","title":"ForexFactory.event/0","doc":"","ref":"ForexFactory.html#t:event/0"},{"type":"type","title":"ForexFactory.opts/0","doc":"","ref":"ForexFactory.html#t:opts/0"},{"type":"type","title":"ForexFactory.type/0","doc":"","ref":"ForexFactory.html#t:type/0"},{"type":"module","title":"ForexFactory.Client","doc":"Client for ForexFactory API","ref":"ForexFactory.Client.html"},{"type":"function","title":"ForexFactory.Client.data/2","doc":"","ref":"ForexFactory.Client.html#data/2"},{"type":"module","title":"ForexFactory.Event","doc":"A specific event with id, type and currency","ref":"ForexFactory.Event.html"},{"type":"type","title":"ForexFactory.Event.frequency/0","doc":"","ref":"ForexFactory.Event.html#t:frequency/0"},{"type":"type","title":"ForexFactory.Event.t/0","doc":"","ref":"ForexFactory.Event.html#t:t/0"},{"type":"module","title":"ForexFactory.Events.CentralBank","doc":"Events from Central Banks","ref":"ForexFactory.Events.CentralBank.html"},{"type":"module","title":"ForexFactory.Events.CentralBank.Rate","doc":"Interest Rate","ref":"ForexFactory.Events.CentralBank.Rate.html"},{"type":"module","title":"ForexFactory.Events.Employment","doc":"Labour events","ref":"ForexFactory.Events.Employment.html"},{"type":"module","title":"ForexFactory.Events.Employment.EmploymentChange","doc":"Change in the number of employed people during the previous period","ref":"ForexFactory.Events.Employment.EmploymentChange.html"},{"type":"module","title":"ForexFactory.Events.Employment.JobCuts","doc":"Change in the number of job cuts announced by employers","ref":"ForexFactory.Events.Employment.JobCuts.html"},{"type":"module","title":"ForexFactory.Events.Employment.JobOpenings","doc":"Number of job openings during the reported period","ref":"ForexFactory.Events.Employment.JobOpenings.html"},{"type":"module","title":"ForexFactory.Events.Employment.JoblessClaims","doc":"The number of individuals who filed for unemployment insurance","ref":"ForexFactory.Events.Employment.JoblessClaims.html"},{"type":"module","title":"ForexFactory.Events.Employment.UnemploymentRate","doc":"Percentage of the total work force that is unemployed and actively seeking employment during the previous","ref":"ForexFactory.Events.Employment.UnemploymentRate.html"},{"type":"module","title":"ForexFactory.Events.Growth","doc":"Economy growth events","ref":"ForexFactory.Events.Growth.html"},{"type":"module","title":"ForexFactory.Events.Growth.CoreRetailSales","doc":"Core retail sales","ref":"ForexFactory.Events.Growth.CoreRetailSales.html"},{"type":"module","title":"ForexFactory.Events.Growth.GDP","doc":"Gross Domestic Product","ref":"ForexFactory.Events.Growth.GDP.html"},{"type":"module","title":"ForexFactory.Events.Growth.RetailSales","doc":"Retail sales","ref":"ForexFactory.Events.Growth.RetailSales.html"},{"type":"module","title":"ForexFactory.Events.Inflation","doc":"Inflation events","ref":"ForexFactory.Events.Inflation.html"},{"type":"module","title":"ForexFactory.Events.Inflation.CPI","doc":"Consumer Price Index","ref":"ForexFactory.Events.Inflation.CPI.html"},{"type":"module","title":"ForexFactory.Events.Inflation.CoreCPI","doc":"Core Consumer Price Index","ref":"ForexFactory.Events.Inflation.CoreCPI.html"},{"type":"module","title":"ForexFactory.Events.Inflation.Earnings","doc":"Average Earnings","ref":"ForexFactory.Events.Inflation.Earnings.html"},{"type":"behaviour","title":"ForexFactory.Events.Type","doc":"Behaviour for all event types","ref":"ForexFactory.Events.Type.html"},{"type":"callback","title":"ForexFactory.Events.Type.all/0","doc":"","ref":"ForexFactory.Events.Type.html#c:all/0"},{"type":"callback","title":"ForexFactory.Events.Type.data/2","doc":"","ref":"ForexFactory.Events.Type.html#c:data/2"},{"type":"callback","title":"ForexFactory.Events.Type.data!/2","doc":"","ref":"ForexFactory.Events.Type.html#c:data!/2"},{"type":"macro","title":"ForexFactory.Events.Type.defevent/1","doc":"","ref":"ForexFactory.Events.Type.html#defevent/1"},{"type":"callback","title":"ForexFactory.Events.Type.event/1","doc":"","ref":"ForexFactory.Events.Type.html#c:event/1"},{"type":"callback","title":"ForexFactory.Events.Type.event!/1","doc":"","ref":"ForexFactory.Events.Type.html#c:event!/1"},{"type":"type","title":"ForexFactory.Events.Type.currency/0","doc":"","ref":"ForexFactory.Events.Type.html#t:currency/0"},{"type":"type","title":"ForexFactory.Events.Type.t/0","doc":"","ref":"ForexFactory.Events.Type.html#t:t/0"},{"type":"module","title":"ForexFactory.HttpClient","doc":"HTTP Client","ref":"ForexFactory.HttpClient.html"},{"type":"function","title":"ForexFactory.HttpClient.api_url/0","doc":"","ref":"ForexFactory.HttpClient.html#api_url/0"},{"type":"function","title":"ForexFactory.HttpClient.get/2","doc":"","ref":"ForexFactory.HttpClient.html#get/2"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}